@@ -1,5 +1,5 @@
 /* This file is part of GNU Dico.
-   Copyright (C) 2008-2016 Sergey Poznyakoff
+   Copyright (C) 2008-2018 Sergey Poznyakoff
 
    GNU Dico is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -42,6 +42,8 @@ dico_list_comp_t dico_list_get_comparator(dico_list_t list);
 
 void dico_list_iterate(dico_list_t list, dico_list_iterator_t itr, void *data);
 void *dico_list_item(dico_list_t list, size_t n);
+void *dico_list_head(struct dico_list *list);
+void *dico_list_tail(struct dico_list *list);
 size_t dico_list_count(dico_list_t list);
 int dico_list_append(dico_list_t list, void *data);
 int dico_list_prepend(dico_list_t list, void *data);
