@@ -1,5 +1,5 @@
 /* This file is part of GNU Dico.
-   Copyright (C) 2012-2016 Sergey Poznyakoff
+   Copyright (C) 2012-2018 Sergey Poznyakoff
 
    GNU Dico is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -205,9 +205,9 @@ wn_init_db(const char *dbname, int argc, char **argv)
 	
     
     struct dico_option init_db_option[] = {
-	{ DICO_OPTSTR(pos), dico_opt_enum, &pos, { enumstr: pos_choice } },
+	{ DICO_OPTSTR(pos), dico_opt_enum, &pos, { .enumstr = pos_choice } },
 	{ DICO_OPTSTR(merge-defs), dico_opt_bool, &flags,
-	  { value: WNDB_MERGE_DEFS } },
+	  { .value = WNDB_MERGE_DEFS } },
 	{ NULL }
     };
 
@@ -684,7 +684,7 @@ wn_exact_match(struct wndb *db, const char *hw)
 {
     struct result *res;
 
-    if (!wn_is_defined(db, hw))
+    if (!wn_is_defined(db, (char*)hw))
 	return NULL;
     res = wn_create_match_result(db);
     dico_list_append(res->list, strdup(hw));
